---
title: ora directory
keywords: documentation
layout: documentation
sidebar: ora_config_sidebar
toc: false
---
## Overview


This resource allows you to manage directory mappings from inside an Oracle database to
a directory outside of the database. Here is an example:

    ora_directory { 'ORACLE_OCM_CONFIG_DIR2@test':
      ensure         => 'present',
      directory_path => '/opt/oracle/app/11.04/ccr/state',
    }

## Attributes



Attribute Name                                                        | Short Description                                                                         |
--------------------------------------------------------------------- | ----------------------------------------------------------------------------------------- |
[directory_name](#ora_directory_directory_name)                       | The directory name
                                                                       |
[directory_path](#ora_directory_directory_path)                       |   	The physical pathname of the directory on the filesystem.                              |
[disable_corrective_change](#ora_directory_disable_corrective_change) | Disable the modification of a resource when Puppet decides it is a corrective change.     |
[disable_corrective_ensure](#ora_directory_disable_corrective_ensure) | Disable the creation or removal of a resource when Puppet decides is a corrective change. |
[ensure](#ora_directory_ensure)                                       | The basic property that the resource should be in.                                        |
[name](#ora_directory_name)                                           | The directory name
                                                                       |
[provider](#ora_directory_provider)                                   | resource.                                                                                 |
[sid](#ora_directory_sid)                                             | SID to connect to.                                                                        |




### directory_name<a name='ora_directory_directory_name'>

The directory name



[Back to overview of ora_directory](#attributes)

### directory_path<a name='ora_directory_directory_path'>

  	The physical pathname of the directory on the filesystem.

ora_directory { 'ORACLE_OCM_CONFIG_DIR2@test':
	...
  directory_path => '/opt/oracle/app/11.04/ccr/state',
  ...
}



[Back to overview of ora_directory](#attributes)

### disable_corrective_change<a name='ora_directory_disable_corrective_change'>

Disable the modification of a resource when Puppet decides it is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_change` parameter, you can disable corrective changes on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ...
      disable_corrective_change => true,
      ...
    }

When a corrective ensure does happen on the resource Puppet will not modify the resource
and signal an error:

        Error: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/parameter: change from '10' to '20' failed: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change. (corrective)



[Back to overview of ora_directory](#attributes)

### disable_corrective_ensure<a name='ora_directory_disable_corrective_ensure'>

Disable the creation or removal of a resource when Puppet decides is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_ensure` parameter, you can disable corrective ensure present or ensure absent actions on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ensure                    => 'present',
      ...
      disable_corrective_ensure => true,
      ...
    }

When a corrective ensure does happen on the resource Puppet will not create or remove the resource
and signal an error:

        Error: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure.
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/ensure: change from 'absent' to 'present' failed: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure. (corrective)



[Back to overview of ora_directory](#attributes)

### ensure<a name='ora_directory_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 

[Back to overview of ora_directory](#attributes)

### name<a name='ora_directory_name'>

The directory name



[Back to overview of ora_directory](#attributes)

### provider<a name='ora_directory_provider'>

The specific backend to use for this `ora_directory`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage directory mappings in an Oracle Database via regular SQL



[Back to overview of ora_directory](#attributes)

### sid<a name='ora_directory_sid'>

SID to connect to.

All types have a name like `resource@sid`. The sid is optional. If you don't specify the sid, the type
will use the database from the `/etc/ora_setting.yaml` with the property `default` set to `true`.
We advise you to either use `@sid` in all your manifests or leave it empty everywhere.



[Back to overview of ora_directory](#attributes)
