---
title: ora feature usage
keywords: documentation
layout: documentation
sidebar: ora_config_sidebar
toc: false
---
## Overview


This resource allows you to report on Database feature usage

    ora_feature_usage { '<feature>@<database>':
      max_usage => 200,
      when_used => 'warning|error',
    }

Managable features are:

    - 'active_data_guard'
    - 'advanced_analytics'
    - 'advanced_compression'
    - 'advanced_security'
    - 'change_management_pack'
    - 'configuration_management_pack_for_oracle_database'
    - 'data_masking_pack'
    - 'database_gateway'
    - 'database_in-memory'
    - 'database_vault'
    - 'diagnostics_pack'
    - 'exadata'
    - 'goldengate'
    - 'hw'
    - 'label_security'
    - 'multitenant'
    - 'olap'
    - 'partitioning'
    - 'pillar_storage'
    - 'provisioning_and_patch_automation_pack'
    - 'provisioning_and_patch_automation_pack_for_database'
    - 'rac_or_rac_one_node'
    - 'real_application_clusters'
    - 'real_application_clusters_one_node'
    - 'real_application_testing'
    - 'secure_backup'
    - 'spatial_and_graph'
    - 'tuning_pack'
    - 'webLogic_server_management_pack_enterprise_edition'

## Attributes



Attribute Name                                                            | Short Description                                                                                             |
------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------- |
[disable_corrective_change](#ora_feature_usage_disable_corrective_change) | Disable the modification of a resource when Puppet decides it is a corrective change.                         |
[disable_corrective_ensure](#ora_feature_usage_disable_corrective_ensure) | Disable the creation or removal of a resource when Puppet decides is a corrective change.                     |
[max_usage](#ora_feature_usage_max_usage)                                 | This resource allows you to specify the maximum usage for a certain Oracle feature
                           |
[name](#ora_feature_usage_name)                                           | The name
                                                                                                     |
[provider](#ora_feature_usage_provider)                                   | resource.                                                                                                     |
[when_used](#ora_feature_usage_when_used)                                 | This resource allows you to specify which type of alert(warning or error) you want when max_usage is reached. |




### disable_corrective_change<a name='ora_feature_usage_disable_corrective_change'>

Disable the modification of a resource when Puppet decides it is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_change` parameter, you can disable corrective changes on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ...
      disable_corrective_change => true,
      ...
    }

When a corrective ensure does happen on the resource Puppet will not modify the resource
and signal an error:

        Error: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/parameter: change from '10' to '20' failed: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change. (corrective)



[Back to overview of ora_feature_usage](#attributes)

### disable_corrective_ensure<a name='ora_feature_usage_disable_corrective_ensure'>

Disable the creation or removal of a resource when Puppet decides is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_ensure` parameter, you can disable corrective ensure present or ensure absent actions on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ensure                    => 'present',
      ...
      disable_corrective_ensure => true,
      ...
    }

When a corrective ensure does happen on the resource Puppet will not create or remove the resource
and signal an error:

        Error: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure.
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/ensure: change from 'absent' to 'present' failed: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure. (corrective)



[Back to overview of ora_feature_usage](#attributes)

### max_usage<a name='ora_feature_usage_max_usage'>


This resource allows you to specify the maximum usage for a certain Oracle feature

    ora_feature_usage { 'advanced_compression@dbname':
      ...
      max_usage => 200,
      ...
    }



[Back to overview of ora_feature_usage](#attributes)

### name<a name='ora_feature_usage_name'>

The name



[Back to overview of ora_feature_usage](#attributes)

### provider<a name='ora_feature_usage_provider'>

The specific backend to use for this `ora_feature_usage`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Report on database feature usage



[Back to overview of ora_feature_usage](#attributes)

### when_used<a name='ora_feature_usage_when_used'>


This resource allows you to specify which type of alert(warning or error) you want when max_usage is reached.

    ora_feature_usage { 'advanced_compression@dbname':
      ...
      when_used => 'warning|error',
      ...
    }

Valid values are `warning`, `WARNING`, `error`, `ERROR`. 

[Back to overview of ora_feature_usage](#attributes)
