---
title: ora home option
keywords: documentation
layout: documentation
sidebar: ora_config_sidebar
toc: false
---
## Overview


This resource allows you to manage(enable/disable) options in an Oracle database home.

    ora_home_option { '/u01/app/oracle/product/12.1.0/db_home1':
      datamining               => 'disabled',
      direct_nfs               => 'disabled',
      olap                     => 'disabled',
      partitioning             => 'disabled',
      real_application_testing => 'disabled',
    }

## Attributes



Attribute Name                                                          | Short Description                                                                                                  |
----------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------ |
[datamining](#ora_home_option_datamining)                               | This resource allows you to manage(enable/disable) the Data Mining RDBMS Files option in an Oracle database home.  |
[direct_nfs](#ora_home_option_direct_nfs)                               | This resource allows you to manage(enable/disable) the DirectNFS option in an Oracle database home.                |
[disable_corrective_change](#ora_home_option_disable_corrective_change) | Disable the modification of a resource when Puppet decides it is a corrective change.                              |
[disable_corrective_ensure](#ora_home_option_disable_corrective_ensure) | Disable the creation or removal of a resource when Puppet decides is a corrective change.                          |
[name](#ora_home_option_name)                                           | The name
                                                                                                          |
[olap](#ora_home_option_olap)                                           | This resource allows you to manage(enable/disable) the OLAP option in an Oracle database home.                     |
[partitioning](#ora_home_option_partitioning)                           | This resource allows you to manage(enable/disable) the Partitioning option in an Oracle database home.             |
[provider](#ora_home_option_provider)                                   | resource.                                                                                                          |
[real_application_testing](#ora_home_option_real_application_testing)   | This resource allows you to manage(enable/disable) the Real Application Testing option in an Oracle database home. |




### datamining<a name='ora_home_option_datamining'>


This resource allows you to manage(enable/disable) the Data Mining RDBMS Files option in an Oracle database home.

    ora_home_option { '/u01/app/oracle/product/12.1.0/db_home1':
      ...
      datamining               => 'enabled',
      ...
    }

Valid values are `disabled`, `enabled`. 

[Back to overview of ora_home_option](#attributes)

### direct_nfs<a name='ora_home_option_direct_nfs'>


This resource allows you to manage(enable/disable) the DirectNFS option in an Oracle database home.

    ora_home_option { '/u01/app/oracle/product/12.1.0/db_home1':
      ...
      direct_nfs               => 'enabled',
      ...
    }

Valid values are `disabled`, `enabled`. 

[Back to overview of ora_home_option](#attributes)

### disable_corrective_change<a name='ora_home_option_disable_corrective_change'>

Disable the modification of a resource when Puppet decides it is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_change` parameter, you can disable corrective changes on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ...
      disable_corrective_change => true,
      ...
    }

When a corrective ensure does happen on the resource Puppet will not modify the resource
and signal an error:

        Error: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/parameter: change from '10' to '20' failed: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change. (corrective)



[Back to overview of ora_home_option](#attributes)

### disable_corrective_ensure<a name='ora_home_option_disable_corrective_ensure'>

Disable the creation or removal of a resource when Puppet decides is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_ensure` parameter, you can disable corrective ensure present or ensure absent actions on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ensure                    => 'present',
      ...
      disable_corrective_ensure => true,
      ...
    }

When a corrective ensure does happen on the resource Puppet will not create or remove the resource
and signal an error:

        Error: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure.
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/ensure: change from 'absent' to 'present' failed: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure. (corrective)



[Back to overview of ora_home_option](#attributes)

### name<a name='ora_home_option_name'>

The name



[Back to overview of ora_home_option](#attributes)

### olap<a name='ora_home_option_olap'>


This resource allows you to manage(enable/disable) the OLAP option in an Oracle database home.

    ora_home_option { '/u01/app/oracle/product/12.1.0/db_home1':
      ...
      olap                     => 'enabled',
      ...
    }

Valid values are `disabled`, `enabled`. 

[Back to overview of ora_home_option](#attributes)

### partitioning<a name='ora_home_option_partitioning'>


This resource allows you to manage(enable/disable) the Partitioning option in an Oracle database home.

    ora_home_option { '/u01/app/oracle/product/12.1.0/db_home1':
      ...
      partitioning             => 'enabled',
      ...
    }

Valid values are `disabled`, `enabled`. 

[Back to overview of ora_home_option](#attributes)

### provider<a name='ora_home_option_provider'>

The specific backend to use for this `ora_home_option`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Enable/disable options in the Oracle kernel



[Back to overview of ora_home_option](#attributes)

### real_application_testing<a name='ora_home_option_real_application_testing'>


This resource allows you to manage(enable/disable) the Real Application Testing option in an Oracle database home.

    ora_home_option { '/u01/app/oracle/product/12.1.0/db_home1':
      ...
      real_application_testing => 'enabled',
      ...
    }

Valid values are `disabled`, `enabled`. 

[Back to overview of ora_home_option](#attributes)
