---
title: ora init param
keywords: documentation
layout: documentation
sidebar: ora_config_sidebar
toc: false
---
## Overview

This resource allows you to manage Oracle parameters.

this type allows you to manage your init.ora parameters. You can manage your `spfile` parameters and your `memory`
parameters. First the easy variant where you want to change an spfile parameter on your current sid for your current sid.

    ora_init_param{'SPFILE/PARAMETER':
      ensure  => present,
      value   => 'the_value'
    }

To manage the same parameter only the in-memory one, use:

    init_param{'MEMORY/PARAMETER':
      ensure  => present,
      value   => 'the_value'
    }

If you are running RAC and need to specify a parameter for an other instance, you can specify the instance as well.

    init_param{'MEMORY/PARAMETER:INSTANCE':
      ensure  => present,
      value   => 'the_value'
    }

Having more then one sid running on your node and you want to specify the sid you want to use, use `@SID` at the end.

    init_param{'MEMORY/PARAMETER:INSTANCE@SID':
      ensure  => present,
      value   => 'the_value'
    }

## Attributes



Attribute Name                                                         | Short Description                                                                         |
---------------------------------------------------------------------- | ----------------------------------------------------------------------------------------- |
[disable_corrective_change](#ora_init_param_disable_corrective_change) | Disable the modification of a resource when Puppet decides it is a corrective change.     |
[disable_corrective_ensure](#ora_init_param_disable_corrective_ensure) | Disable the creation or removal of a resource when Puppet decides is a corrective change. |
[ensure](#ora_init_param_ensure)                                       | The basic property that the resource should be in.                                        |
[for_sid](#ora_init_param_for_sid)                                     | The SID you want to set the parameter for.                                                |
[name](#ora_init_param_name)                                           | The parameter name.                                                                       |
[parameter_name](#ora_init_param_parameter_name)                       | The parameter name.                                                                       |
[provider](#ora_init_param_provider)                                   | resource.                                                                                 |
[scope](#ora_init_param_scope)                                         | The scope of the change.                                                                  |
[sid](#ora_init_param_sid)                                             | SID to connect to.                                                                        |
[value](#ora_init_param_value)                                         | The value or values of the parameter.                                                     |




### disable_corrective_change<a name='ora_init_param_disable_corrective_change'>

Disable the modification of a resource when Puppet decides it is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_change` parameter, you can disable corrective changes on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ...
      disable_corrective_change => true,
      ...
    }

When a corrective ensure does happen on the resource Puppet will not modify the resource
and signal an error:

        Error: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/parameter: change from '10' to '20' failed: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change. (corrective)



[Back to overview of ora_init_param](#attributes)

### disable_corrective_ensure<a name='ora_init_param_disable_corrective_ensure'>

Disable the creation or removal of a resource when Puppet decides is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_ensure` parameter, you can disable corrective ensure present or ensure absent actions on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ensure                    => 'present',
      ...
      disable_corrective_ensure => true,
      ...
    }

When a corrective ensure does happen on the resource Puppet will not create or remove the resource
and signal an error:

        Error: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure.
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/ensure: change from 'absent' to 'present' failed: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure. (corrective)



[Back to overview of ora_init_param](#attributes)

### ensure<a name='ora_init_param_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 

[Back to overview of ora_init_param](#attributes)

### for_sid<a name='ora_init_param_for_sid'>

The SID you want to set the parameter for.



[Back to overview of ora_init_param](#attributes)

### name<a name='ora_init_param_name'>

The parameter name.



[Back to overview of ora_init_param](#attributes)

### parameter_name<a name='ora_init_param_parameter_name'>

The parameter name.



[Back to overview of ora_init_param](#attributes)

### provider<a name='ora_init_param_provider'>

The specific backend to use for this `ora_init_param`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage Oracle Instance Parameters in an Oracle Database via regular SQL



[Back to overview of ora_init_param](#attributes)

### scope<a name='ora_init_param_scope'>

The scope of the change.

Valid values are `SPFILE`, `MEMORY`, `spfile`, `memory`. 

[Back to overview of ora_init_param](#attributes)

### sid<a name='ora_init_param_sid'>

SID to connect to.

All types have a name like `resource@sid`. The sid is optional. If you don't specify the sid, the type
will use the database from the `/etc/ora_setting.yaml` with the property `default` set to `true`.
We advise you to either use `@sid` in all your manifests or leave it empty everywhere.



[Back to overview of ora_init_param](#attributes)

### value<a name='ora_init_param_value'>

The value or values of the parameter.

You can use either a single value or an Array value. Although not strictly required, we
reccomend that you alsways use quoted values. Also when using nummeric or boolean values.


An example  using a boolean value:

    ora_init_param { ....:
      ...
      value  => 'FALSE',
    }

Here an example using an array of values:

    ora_init_param { ....:
      ...
      value  => ['RECODG', 'BACKUPDG', 'DATADG'],
    }

    ora_init_param { ...:
      ...
      value  => '1',
    }



[Back to overview of ora_init_param](#attributes)
